@@ -45,6 +45,7 @@ from google.protobuf import field_mask_pb2  # type: ignore
 from .transports.base import CatalogServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import CatalogServiceGrpcTransport
 from .transports.grpc_asyncio import CatalogServiceGrpcAsyncIOTransport
+from .transports.rest import CatalogServiceRestTransport
 
 
 class CatalogServiceClientMeta(type):
@@ -60,6 +61,7 @@ class CatalogServiceClientMeta(type):
     )  # type: Dict[str, Type[CatalogServiceTransport]]
     _transport_registry["grpc"] = CatalogServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = CatalogServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = CatalogServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -355,6 +357,9 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
             transport (Union[str, CatalogServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -432,6 +437,7 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_catalog_item(
@@ -448,6 +454,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_create_catalog_item():
@@ -457,7 +470,7 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
                 # Initialize request argument(s)
                 catalog_item = recommendationengine_v1beta1.CatalogItem()
                 catalog_item.id = "id_value"
-                catalog_item.category_hierarchies.categories = ['categories_value_1', 'categories_value_2']
+                catalog_item.category_hierarchies.categories = ['categories_value1', 'categories_value2']
                 catalog_item.title = "title_value"
 
                 request = recommendationengine_v1beta1.CreateCatalogItemRequest(
@@ -556,6 +569,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_get_catalog_item():
@@ -652,6 +672,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_list_catalog_items():
@@ -772,6 +799,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_update_catalog_item():
@@ -781,7 +815,7 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
                 # Initialize request argument(s)
                 catalog_item = recommendationengine_v1beta1.CatalogItem()
                 catalog_item.id = "id_value"
-                catalog_item.category_hierarchies.categories = ['categories_value_1', 'categories_value_2']
+                catalog_item.category_hierarchies.categories = ['categories_value1', 'categories_value2']
                 catalog_item.title = "title_value"
 
                 request = recommendationengine_v1beta1.UpdateCatalogItemRequest(
@@ -892,6 +926,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_delete_catalog_item():
@@ -984,6 +1025,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_import_catalog_items():
