@@ -43,6 +43,7 @@ from google.cloud.recommendationengine_v1beta1.types import (
 from .transports.base import PredictionApiKeyRegistryTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import PredictionApiKeyRegistryGrpcTransport
 from .transports.grpc_asyncio import PredictionApiKeyRegistryGrpcAsyncIOTransport
+from .transports.rest import PredictionApiKeyRegistryRestTransport
 
 
 class PredictionApiKeyRegistryClientMeta(type):
@@ -58,6 +59,7 @@ class PredictionApiKeyRegistryClientMeta(type):
     )  # type: Dict[str, Type[PredictionApiKeyRegistryTransport]]
     _transport_registry["grpc"] = PredictionApiKeyRegistryGrpcTransport
     _transport_registry["grpc_asyncio"] = PredictionApiKeyRegistryGrpcAsyncIOTransport
+    _transport_registry["rest"] = PredictionApiKeyRegistryRestTransport
 
     def get_transport_class(
         cls,
@@ -385,6 +387,9 @@ class PredictionApiKeyRegistryClient(metaclass=PredictionApiKeyRegistryClientMet
             transport (Union[str, PredictionApiKeyRegistryTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -462,6 +467,7 @@ class PredictionApiKeyRegistryClient(metaclass=PredictionApiKeyRegistryClientMet
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_prediction_api_key_registration(
@@ -481,6 +487,13 @@ class PredictionApiKeyRegistryClient(metaclass=PredictionApiKeyRegistryClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_create_prediction_api_key_registration():
@@ -596,6 +609,13 @@ class PredictionApiKeyRegistryClient(metaclass=PredictionApiKeyRegistryClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_list_prediction_api_key_registrations():
@@ -714,6 +734,13 @@ class PredictionApiKeyRegistryClient(metaclass=PredictionApiKeyRegistryClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_delete_prediction_api_key_registration():
