@@ -47,6 +47,7 @@ from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import UserEventServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import UserEventServiceGrpcTransport
 from .transports.grpc_asyncio import UserEventServiceGrpcAsyncIOTransport
+from .transports.rest import UserEventServiceRestTransport
 
 
 class UserEventServiceClientMeta(type):
@@ -62,6 +63,7 @@ class UserEventServiceClientMeta(type):
     )  # type: Dict[str, Type[UserEventServiceTransport]]
     _transport_registry["grpc"] = UserEventServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = UserEventServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = UserEventServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -359,6 +361,9 @@ class UserEventServiceClient(metaclass=UserEventServiceClientMeta):
             transport (Union[str, UserEventServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -436,6 +441,7 @@ class UserEventServiceClient(metaclass=UserEventServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def write_user_event(
@@ -452,6 +458,13 @@ class UserEventServiceClient(metaclass=UserEventServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_write_user_event():
@@ -569,6 +582,13 @@ class UserEventServiceClient(metaclass=UserEventServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_collect_user_event():
@@ -747,6 +767,13 @@ class UserEventServiceClient(metaclass=UserEventServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_list_user_events():
@@ -904,6 +931,13 @@ class UserEventServiceClient(metaclass=UserEventServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_purge_user_events():
@@ -1063,6 +1097,13 @@ class UserEventServiceClient(metaclass=UserEventServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             def sample_import_user_events():
